def decode_int16(buffer, unpacker):
    requested_bytes = buffer[:2]
    return unpacker.unpack('h', requested_bytes)[0]


def decode_int24(buffer, unpacker):
    requested_bytes = buffer[:3]
    byte_order = 'big' if unpacker.byte_order_char == '>' else 'little'
    # We delegate to int.from_bytes() because it takes a lot of work to make
    # struct.unpack() handle signed 24-bits integers.
    # See: https://stackoverflow.com/questions/3783677/how-to-read-integers-from-a-file-that-are-24bit-and-little-endian-using-python  # noqa
    return int.from_bytes(requested_bytes, byte_order)


def decode_int32(buffer, unpacker):
    requested_bytes = buffer[:4]
    return unpacker.unpack('i', requested_bytes)[0]


def decode_ieee_float(buffer, unpacker):
    requested_bytes = buffer[:4]
    return unpacker.unpack('f', requested_bytes)[0]


def decode_ieee_double(buffer, unpacker):
    requested_bytes = buffer[:8]
    return unpacker.unpack('d', requested_bytes)[0]


def decode_steim(buffer, unpacker):
    # The first 4 bytes in a Steim frame is metadata of the record. Since we
    # aren't decompressing the data, we are skipping. The next 4 bytes contain
    # the first data point of the MSEED data record, which is what we need.
    requested_bytes = buffer[4:8]
    return unpacker.unpack('i', requested_bytes)[0]
